metaindex
=========

.. include:: description.rst


Content
=======

.. toctree::
   :maxdepth: 1

   install
   changelog
   usage
   configuration
   searchsyntax
   extrametadata
   indexers
   addons
   examples
   license
   reference

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
